==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QMoveEvent_shell.cpp <==
#include "QMoveEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QMoveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMoveEvent")
    QMoveEvent *_ptr = reinterpret_cast<QMoveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMoveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMoveEvent_shell) ); }

jmethodID QMoveEvent_shell::__shell_javaMethod(int pos) const { return QMoveEvent_shell::__shell()->javaMethod(typeid(QMoveEvent), pos); }

// emitting (writeShellConstructor)
QMoveEvent_shell::QMoveEvent_shell(const QMoveEvent& arg__1)
    : QMoveEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QMoveEvent& arg__1)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

QMoveEvent_shell::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)
    : QMoveEvent(pos0, oldPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

// emitting (writeShellDestructor)
QMoveEvent_shell::~QMoveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMoveEvent::~QMoveEvent()", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->destructed(typeid(QMoveEvent));
}

void QMoveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMoveEvent_shell*>(ptr)->QMoveEvent_shell::__shell()->tryDeleteShell(typeid(QMoveEvent));
}

// emitting Virtual overrides (virtualFunctions)
QMoveEvent* QMoveEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QMoveEvent::clone()const", QMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QMoveEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QMoveEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QMoveEvent_shell::__shell()->warnForMethod("QMoveEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMoveEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QMoveEvent::clone();
        }
    }else{
        return QMoveEvent::clone();
    }
}

void QMoveEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QMoveEvent::", QMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QMoveEvent_shell::__shell()->warnForMethod("QMoveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMoveEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QMoveEvent_access::__qt_assign_cref_QMoveEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QMoveEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QMoveEvent>(__jni_env, other0);
    QMoveEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QMoveEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QMoveEvent* __qt_return_value = QMoveEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QMoveEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QMoveEvent(QMoveEvent)
void __qt_construct_QMoveEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QMoveEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QMoveEvent& __qt_arg__1 = qtjambi_cast<const QMoveEvent& >(__jni_env, arg__1);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QMoveEvent(QPoint,QPoint)
void __qt_construct_QMoveEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QPoint,QPoint)")
    jobject pos0 = __java_arguments[0].l;
    const QPoint& __qt_pos0 = qtjambi_cast<const QPoint& >(__jni_env, pos0);
    jobject oldPos1 = __java_arguments[1].l;
    const QPoint& __qt_oldPos1 = qtjambi_cast<const QPoint& >(__jni_env, oldPos1);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_pos0, __qt_oldPos1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QMoveEvent_shell
void __qt_destruct_QMoveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMoveEvent")
    reinterpret_cast<QMoveEvent_shell*>(ptr)->~QMoveEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMoveEvent::QMoveEvent(QMoveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_gui_QMoveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QMoveEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_0, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMoveEvent::QMoveEvent(QPoint,QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_core_QPoint_2Lio_qt_core_QPoint_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject pos0,
 jobject oldPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QPoint,QPoint)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = pos0;
        arguments[1].l = oldPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_1, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMoveEvent::oldPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_oldPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::oldPos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->oldPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMoveEvent::operator=(QMoveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_assign_1native_1cref_1QMoveEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::operator=(QMoveEvent)", __qt_this)
        static_cast<QMoveEvent_access*>(__qt_this)->__qt_assign_cref_QMoveEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMoveEvent::pos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_pos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::pos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->pos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMoveEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QMoveEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMoveEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMoveEvent>("QMoveEvent", "io/qt/gui/QMoveEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QMoveEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QMoveEvent, {
        ConstructorInfo(&__qt_construct_QMoveEvent_0, "Lio/qt/gui/QMoveEvent;")
       ,ConstructorInfo(&__qt_construct_QMoveEvent_1, "Lio/qt/core/QPoint;Lio/qt/core/QPoint;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMoveEvent);
    registerSizeOfShell(typeId, sizeof(QMoveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QMoveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QMoveEvent_shell.cpp <==
#include "QMoveEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QMoveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMoveEvent")
    QMoveEvent *_ptr = reinterpret_cast<QMoveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMoveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMoveEvent_shell) ); }

jmethodID QMoveEvent_shell::__shell_javaMethod(int pos) const { return QMoveEvent_shell::__shell()->javaMethod(typeid(QMoveEvent), pos); }

// emitting (writeShellConstructor)
QMoveEvent_shell::QMoveEvent_shell(const QMoveEvent& arg__1)
    : QMoveEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QMoveEvent& arg__1)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

QMoveEvent_shell::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)
    : QMoveEvent(pos0, oldPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

// emitting (writeShellDestructor)
QMoveEvent_shell::~QMoveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMoveEvent::~QMoveEvent()", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->destructed(typeid(QMoveEvent));
}

void QMoveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMoveEvent_shell*>(ptr)->QMoveEvent_shell::__shell()->tryDeleteShell(typeid(QMoveEvent));
}

// emitting Virtual overrides (virtualFunctions)
QMoveEvent* QMoveEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QMoveEvent::clone()const", QMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QMoveEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QMoveEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QMoveEvent_shell::__shell()->warnForMethod("QMoveEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMoveEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QMoveEvent::clone();
        }
    }else{
        return QMoveEvent::clone();
    }
}

void QMoveEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QMoveEvent::", QMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QMoveEvent_shell::__shell()->warnForMethod("QMoveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QMoveEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QMoveEvent_access::__qt_assign_cref_QMoveEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QMoveEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QMoveEvent>(__jni_env, other0);
    QMoveEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QMoveEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QMoveEvent* __qt_return_value = QMoveEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QMoveEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QMoveEvent(QMoveEvent)
void __qt_construct_QMoveEvent_cref_QMoveEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QMoveEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QMoveEvent& __qt_arg__1 = qtjambi_cast<const QMoveEvent& >(__jni_env, arg__1);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QMoveEvent::QMoveEvent(QMoveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_gui_QMoveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QMoveEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_cref_QMoveEvent, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QMoveEvent(QPoint,QPoint)
void __qt_construct_QMoveEvent_cref_QPoint_cref_QPoint(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QPoint,QPoint)")
    jobject pos0 = __java_arguments[0].l;
    const QPoint& __qt_pos0 = qtjambi_cast<const QPoint& >(__jni_env, pos0);
    jobject oldPos1 = __java_arguments[1].l;
    const QPoint& __qt_oldPos1 = qtjambi_cast<const QPoint& >(__jni_env, oldPos1);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_pos0, __qt_oldPos1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QMoveEvent::QMoveEvent(QPoint,QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_core_QPoint_2Lio_qt_core_QPoint_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject pos0,
 jobject oldPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QPoint,QPoint)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = pos0;
        arguments[1].l = oldPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_cref_QPoint_cref_QPoint, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMoveEvent_shell
void __qt_destruct_QMoveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMoveEvent")
    reinterpret_cast<QMoveEvent_shell*>(ptr)->~QMoveEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMoveEvent::oldPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_oldPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::oldPos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->oldPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMoveEvent::operator=(QMoveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_assign_1native_1cref_1QMoveEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::operator=(QMoveEvent)", __qt_this)
        static_cast<QMoveEvent_access*>(__qt_this)->__qt_assign_cref_QMoveEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMoveEvent::pos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_pos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::pos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->pos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMoveEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QMoveEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMoveEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMoveEvent>("QMoveEvent", "io/qt/gui/QMoveEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QMoveEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QMoveEvent, {
        ConstructorInfo(&__qt_construct_QMoveEvent_cref_QMoveEvent, "Lio/qt/gui/QMoveEvent;")
       ,ConstructorInfo(&__qt_construct_QMoveEvent_cref_QPoint_cref_QPoint, "Lio/qt/core/QPoint;Lio/qt/core/QPoint;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMoveEvent);
    registerSizeOfShell(typeId, sizeof(QMoveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QMoveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
